@@ -92,7 +92,7 @@ def update_version(
     for leftover in leftovers:
         new_requirement.append(
             update_version(
-                leftover,
+                leftover.strip(),
                 operator=None,
                 package_name=package_name
             )
